# Your Package Name

[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![Python Version](https://img.shields.io/badge/python-3.12-blue)](https://www.python.org/downloads/release/python-390/)

## Description

The Pypox framework is designed to be fast and easy to use. It is a high-performance, easy-to-learn, and fast-to-code framework that is in active development. It is designed to be ready for production and is used in production by many companies.

## Features

- File based routing
- Processor based system
- Middleware support
- OpenAPI and JSON Schema support (via Pydantic). Coming soon!

## Installation

You can install the package using pip:

```bash
pip install pypox
```

## Documentation

You can find the documentation at [link to documentation](https://po-key.github.io/pypox/)
